bootload_dfu

Function bootload_dfu 

pub fn bootload_dfu()
Execute the DFU bootloader stored in system memory.

Note

This function must be called before any system configuration is performed, as the DFU bootloader expects the system in an uninitialized state.